Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1734)

Unified Diff: chrome/browser/engagement/site_engagement_service.h

Issue 1338603002: Implement a site engagement score based on time-on-site. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: More web contents validity checking Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/engagement/site_engagement_service.h
diff --git a/chrome/browser/engagement/site_engagement_service.h b/chrome/browser/engagement/site_engagement_service.h
index 60644a4a4e3f504721d10a8a2e0666eb635dac34..d6b82102c4fd9cc48b3e359d9d658f1beaa07694 100644
--- a/chrome/browser/engagement/site_engagement_service.h
+++ b/chrome/browser/engagement/site_engagement_service.h
@@ -31,8 +31,8 @@ class SiteEngagementScore {
// The maximum number of points that can be accrued in one day.
static const double kMaxPointsPerDay;
- // The number of points given for a navigation.
- static const double kNavigationPoints;
+ // The number of points given for user input (indicating time-on-site).
+ static const double kUserInputPoints;
// Decaying works by removing a portion of the score periodically. This
// constant determines how often that happens.
@@ -114,8 +114,9 @@ class SiteEngagementService : public KeyedService,
explicit SiteEngagementService(Profile* profile);
~SiteEngagementService() override;
- // Update the karma score of the origin matching |url| for user navigation.
- void HandleNavigation(const GURL& url);
+ // Update the karma score of the origin matching |url| for time-on-site, based
+ // on user input.
+ void HandleUserInput(const GURL& url);
// Overridden from SiteEngagementScoreProvider:
int GetScore(const GURL& url) override;

Powered by Google App Engine
This is Rietveld 408576698